pub fn classify_search(query: &str) -> SearchIntentExpand description
Guess what the user meant by the text in the list-page search box. Order of tries: numeric → email → personnummer → text.
pub fn classify_search(query: &str) -> SearchIntentGuess what the user meant by the text in the list-page search box. Order of tries: numeric → email → personnummer → text.