pub struct RenameModel {
pub from: String,
pub to: String,
}Expand description
Rename a model (schema-level). Data-preserving: the AI executor must translate this into a table rename, not a drop+recreate.
Fields
from: Stringto: StringTrait Implementations
Sourceimpl Clone for RenameModel
impl Clone for RenameModel
Sourcefn clone(&self) -> RenameModel
fn clone(&self) -> RenameModel
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RenameModel
impl Debug for RenameModel
Sourceimpl<'de> Deserialize<'de> for RenameModel
impl<'de> Deserialize<'de> for RenameModel
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for RenameModel
impl PartialEq for RenameModel
Sourcefn eq(&self, other: &RenameModel) -> bool
fn eq(&self, other: &RenameModel) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RenameModel
impl Serialize for RenameModel
impl StructuralPartialEq for RenameModel