Request

Struct Request 

pub struct Request { /* private fields */ }
Incoming HTTP request with an attached per-request Context.

Implementations

Source

impl Request

pub fn ctx(&self) -> &Context

Read-only access to the per-request Context.

Examples found in repository?
examples/homepage.rs (line 27)
24async fn logger(req: Request, next: Next) -> Result<Response, Error> {
25    let method = req.method().clone();
26    let path = req.uri().path().to_owned();
27    let id = req.ctx().get::<RequestId>().map(|r| r.0);
28    let user = rustio_core::auth::identity(req.ctx()).map(|i| i.user_id.clone());
29    let started = Instant::now();
30    let result = next.run(req).await;
31    let status = match &result {
32        Ok(resp) => resp.status().as_u16(),
33        Err(err) => err.status(),
34    };
35    let id_display = id.map(|i| format!("req-{i}")).unwrap_or_else(|| "-".into());
36    let user_display = user.unwrap_or_else(|| "-".into());
37    eprintln!(
38        "[{:>3}] {:>4} {} id={} user={} ({:?})",
39        status,
40        method,
41        path,
42        id_display,
43        user_display,
44        started.elapsed()
45    );
46    result
47}
48
49#[tokio::main]
50async fn main() -> std::io::Result<()> {
51    let addr: SocketAddr = ([127, 0, 0, 1], 3000).into();
52    let router = with_defaults(Router::new())
53        .get("/whoami", |req, _params| async move {
54            let id = req
55                .ctx()
56                .get::<RequestId>()
57                .map(|r| r.0.to_string())
58                .unwrap_or_else(|| "unknown".into());
59            Ok::<Response, Error>(text(format!("your request id is req-{id}\n")))
60        })
61        .get("/me", |req, _params| async move {
62            let id = require_auth(req.ctx())?;
63            Ok::<Response, Error>(text(format!("hello {}\n", id.user_id)))
64        })
65        .get("/admin-only", |req, _params| async move {
66            let id = require_admin(req.ctx())?;
67            Ok::<Response, Error>(text(format!("hello admin {}\n", id.user_id)))
68        })
69        .get("/crash", |_req, _params| async {
70            Err::<Response, Error>(Error::Internal("simulated failure".into()))
71        })
72        .get("/unauth", |_req, _params| async {
73            Err::<Response, Error>(Error::Unauthorized)
74        })
75        .wrap(request_id)
76        .wrap(authenticate)
77        .wrap(logger);
78    Server::bind(addr).serve_router(router).await
79}
pub fn ctx_mut(&mut self) -> &mut Context

Mutable access to the per-request Context.

Examples found in repository?
examples/homepage.rs (line 16)
14async fn request_id(mut req: Request, next: Next) -> Result<Response, Error> {
15    let id = REQUEST_COUNTER.fetch_add(1, Ordering::Relaxed);
16    req.ctx_mut().insert(RequestId(id));
17    let mut resp = resolve(next.run(req).await);
18    if let Ok(header) = format!("req-{id}").parse() {
19        resp.headers_mut().insert("x-request-id", header);
20    }
21    Ok(resp)
22}
pub fn query(&self) -> FormData

Parse the URL query string into a FormData.

Returns an empty FormData when the request has no query string.

pub fn into_parts(self) -> (Parts, Incoming, Context)

Consume this request, returning the underlying hyper parts, body, and the attached context.

Methods from Deref<Target = Request<Incoming>>

pub fn method(&self) -> &Method

Returns a reference to the associated HTTP method.

Examples
let request: Request<()> = Request::default();
assert_eq!(*request.method(), Method::GET);
Examples found in repository?
examples/homepage.rs (line 25)
24async fn logger(req: Request, next: Next) -> Result<Response, Error> {
25    let method = req.method().clone();
26    let path = req.uri().path().to_owned();
27    let id = req.ctx().get::<RequestId>().map(|r| r.0);
28    let user = rustio_core::auth::identity(req.ctx()).map(|i| i.user_id.clone());
29    let started = Instant::now();
30    let result = next.run(req).await;
31    let status = match &result {
32        Ok(resp) => resp.status().as_u16(),
33        Err(err) => err.status(),
34    };
35    let id_display = id.map(|i| format!("req-{i}")).unwrap_or_else(|| "-".into());
36    let user_display = user.unwrap_or_else(|| "-".into());
37    eprintln!(
38        "[{:>3}] {:>4} {} id={} user={} ({:?})",
39        status,
40        method,
41        path,
42        id_display,
43        user_display,
44        started.elapsed()
45    );
46    result
47}
pub fn method_mut(&mut self) -> &mut Method

Returns a mutable reference to the associated HTTP method.

Examples
let mut request: Request<()> = Request::default();
*request.method_mut() = Method::PUT;
assert_eq!(*request.method(), Method::PUT);
pub fn uri(&self) -> &Uri

Returns a reference to the associated URI.

Examples
let request: Request<()> = Request::default();
assert_eq!(*request.uri(), *"/");
Examples found in repository?
examples/homepage.rs (line 26)
24async fn logger(req: Request, next: Next) -> Result<Response, Error> {
25    let method = req.method().clone();
26    let path = req.uri().path().to_owned();
27    let id = req.ctx().get::<RequestId>().map(|r| r.0);
28    let user = rustio_core::auth::identity(req.ctx()).map(|i| i.user_id.clone());
29    let started = Instant::now();
30    let result = next.run(req).await;
31    let status = match &result {
32        Ok(resp) => resp.status().as_u16(),
33        Err(err) => err.status(),
34    };
35    let id_display = id.map(|i| format!("req-{i}")).unwrap_or_else(|| "-".into());
36    let user_display = user.unwrap_or_else(|| "-".into());
37    eprintln!(
38        "[{:>3}] {:>4} {} id={} user={} ({:?})",
39        status,
40        method,
41        path,
42        id_display,
43        user_display,
44        started.elapsed()
45    );
46    result
47}
pub fn uri_mut(&mut self) -> &mut Uri

Returns a mutable reference to the associated URI.

Examples
let mut request: Request<()> = Request::default();
*request.uri_mut() = "/hello".parse().unwrap();
assert_eq!(*request.uri(), *"/hello");
pub fn version(&self) -> Version

Returns the associated version.

Examples
let request: Request<()> = Request::default();
assert_eq!(request.version(), Version::HTTP_11);
pub fn version_mut(&mut self) -> &mut Version

Returns a mutable reference to the associated version.

Examples
let mut request: Request<()> = Request::default();
*request.version_mut() = Version::HTTP_2;
assert_eq!(request.version(), Version::HTTP_2);
pub fn headers(&self) -> &HeaderMap

Returns a reference to the associated header field map.

Examples
let request: Request<()> = Request::default();
assert!(request.headers().is_empty());
pub fn headers_mut(&mut self) -> &mut HeaderMap

Returns a mutable reference to the associated header field map.

Examples
let mut request: Request<()> = Request::default();
request.headers_mut().insert(HOST, HeaderValue::from_static("world"));
assert!(!request.headers().is_empty());
pub fn extensions(&self) -> &Extensions

Returns a reference to the associated extensions.

Examples
let request: Request<()> = Request::default();
assert!(request.extensions().get::<i32>().is_none());
pub fn extensions_mut(&mut self) -> &mut Extensions

Returns a mutable reference to the associated extensions.

Examples
let mut request: Request<()> = Request::default();
request.extensions_mut().insert("hello");
assert_eq!(request.extensions().get(), Some(&"hello"));
pub fn body(&self) -> &T

Returns a reference to the associated HTTP body.

Examples
let request: Request<String> = Request::default();
assert!(request.body().is_empty());
pub fn body_mut(&mut self) -> &mut T

Returns a mutable reference to the associated HTTP body.

Examples
let mut request: Request<String> = Request::default();
request.body_mut().push_str("hello world");
assert!(!request.body().is_empty());